Consumer Price Index for Urban Consumers (CPI-U) data
cpi_u.RdMonthly, quarterly, or annual CPI-U price indexes
Format
The data frames cpi_u_monthly_sa and cpi_u_monthly_nsa
contain, respectively, seasonally adjusted or not seasonally adjusted monthly
price index levels of the CPI-U. They have three columns:
- year
numeric year
- month
numeric calendar month (1-12)
- cpi_u
value of the CPI-U price index
#' @format The data frames cpi_u_quarterly_sa and cpi_u_quarterly_nsa
contain, respectively, seasonally adjusted or not seasonally adjusted quarterly
price index levels of the CPI-U. They have three columns:
- year
numeric year
- quarter
numeric calendar quarter (1-4)
- cpi_u
value of the CPI-U price index
The data frame cpi_u_annual contains the annual
price index level of the CPI-U. It has two columns:
- year
numeric year
- cpi_u
value of the CPI-U price index
See also
cpi_u_rs_monthly_nsa and cpi_u_rs_annual
for the CPI-U-RS, an index that is more consistent over time than the CPI-U
and incorporates more recent improvements to the CPI-U into the
entire time series. The quarterly cpi_u_quarterly_nsa and
cpi_u_quarterly_sa series are the quarterly means of their
respective monthly series.