Consumer Price Index for Urban Consumers Research Series (CPI-U-RS) data
cpi_u_rs.RdMonthly or annual CPI-U-RS price indexes
Format
The data frame cpi_u_rs_monthly_nsa contains the
not seasonally adjusted monthly price index levels of the CPI-U-RS
(CPI-U research series). The CPI-U-RS is more consistent over time than
the CPI-U and incorporates more recent improvements to the CPI-U into the
entire time series. It has three columns:
- year
numeric year
- month
numeric calendar month (1-12)
- cpi_u_rs
value of the CPI-U-RS price index
The data frame cpi_u_rs_annual contains the annual
price index level of the CPI-U-RS. It has two columns:
- year
numeric year
- cpi_u_rs
value of the CPI-U-RS price index
See also
c_cpi_u_extended_annual extends the
CPI-U-RS from 1937 to the present using the c_cpi_u and other series.